#!/usr/bin/env python

from tileviewer import cmdline

if __name__ == '__main__':
    cmdline.run()
